# Reptile

Установить все зависимости `pip install -r requirements.txt`.  
Подвязать хук на линтер `flake8 --install-hook git`.  
Пролинтовать весь проект `flake8 .`.  
Запустить тесты `./src/tests.py`.  

## Документация

1. [Network](https://gitlab.com/st0nks/reptile/-/tree/master/src/Network)
2. [Constructor](https://gitlab.com/st0nks/reptile/-/tree/master/src/Constructor)
3. [Layer](https://gitlab.com/st0nks/reptile/-/tree/master/src/Layer)
4. [ActFunctions](https://gitlab.com/st0nks/reptile/-/tree/master/src/ActFunctions)
5. [Core](https://gitlab.com/st0nks/reptile/-/tree/master/src/Core)
6. [Tests](https://gitlab.com/st0nks/reptile/-/tree/master/src/__tests__)
